```shell
npm install mp-components
```

# Components

> mp-nav-bar
>
> mp-tab
>
> mp-ellipsis
> 
> mp-popup
> 
> mp-dropdown-menu
> 
> mp-dropdown-menu-item
> 
> mp-button
> 
> mp-button-group
> 
> mp-box
> 
> mp-dots
> 
> mp-pk-card
> 
> mp-pk-progress-bar
> 
> mp-image

## mp-nav-bar

- properties

> bg: String、 zIndex: Number、 custom: Boolean

- events

> height

- slots

> left、title、 default
>

*Tip:* If the custom property is true, the left and title slots are invalid

### Demo

```wxml

<mp-nav-bar custom="{{true}}">
    <view slot="left">back</view>
    <view slot="title">title</view>
    <view>custom</view>
</mp-nav-bar>
```

## mp-ellipsis

- properties

> content: String、 contentClass: String、 contentStyle: String、 rows: Number、 size: String、 lineHeight:
> String、ellipsisColor: String、forceShowSlot： Boolean, forceShowSlotPosition: 'end' | 'suffix', isAsync: Boolean, offset: Number

- slot

> default

### Demo

```wxml

<mp-ellipsis content="what???" rows="{{2}}">
    <view>Slot</view>
</mp-ellipsis>
```

## mp-tab

- properties

> data: Array、 labelField: String | null、 active: Number、 height: String、gap: String、size: String、activeSize: String、color: String、 activeColor: String、 activeLineHeight: String、 activeLineColor: String、 border: String、 borderColor: String
> start: Number、end: Number  => font-size animation scale from size to start and then end

- events

> change

### Demo

```wxml

<comp data="{{['tab1', 'tab2']}}" height="120rpx" active="{{curTab}}" itemClass="item" catch:change='onChange'></comp>
```

## mp-popup

- properties

> visible: Boolean、 bg: String、 maskClosable: Boolean、 duration: Number、 type: String、 contentClass: String
>
> type -> bottom、top、left、right、center、center-scale

- events

> open、opened、close、 closed

- slot

> default

## mp-dropdown-menu

- properties

> duration: Number、 bg: String、 maskClosable: Boolean

- events

> open、opened、close、 closed、 change

- methods

> close

- slot

> default

## mp-dropdown-menu-item

- slot

> default、 title


```wxml

<mp-dropdown-menu maskClosable="{{true}}" catch:change="onMenuChange" catch:close="close" catch:closed="closed"
                  catch:open="open" catch:opened="opened">
    <mp-dropdown-menu-item>
        <view slot="title" class="menu-item">One</view>
        <view style="background: #ffffff;">Content</view>
    </mp-dropdown-menu-item>
    <mp-dropdown-menu-item>
        <view slot="title" class="menu-item">Two</view>
        <view style="background: #ffffff;">Content2</view>
    </mp-dropdown-menu-item>
    <mp-dropdown-menu-item>
        <view slot="title" class="menu-item">Three</view>
        <view style="background: #ffffff;">Content3</view>
    </mp-dropdown-menu-item>
</mp-dropdown-menu>
```

```css
.menu-item {
    width: 100%;
    padding: 20 rpx 0;
}
```

## mp-button

- properties

> disabled: Boolean、 padding: String、 loading: Boolean、 loadingSize: Boolean、 dark: Boolean、 ghostDark: Boolean、 ghostLight: Boolean、borderWidth: String

- event

> tap

```wxml
<mp-button bindtap="handleTap">
    填充按钮
</mp-button>
```

### Effect
<img src="https://gynycvhskjtbtmvgjdoz.supabase.co/storage/v1/object/sign/static/button.png?token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1cmwiOiJzdGF0aWMvYnV0dG9uLnBuZyIsImlhdCI6MTY4NjAxOTg1NiwiZXhwIjo0ODQ4MjU5ODU2fQ.Xat0o_Mlstj6f5RvB9OxeBo6SDeaUU13xkK8vDy-Wh0&t=2023-06-06T02%3A50%3A56.743Z">


## mp-button-group

- properties

> gap: String


```wxml
<mp-button-group>
    <mp-button ghostLight>了解详情</mp-button>
    <mp-button ghostDark>立即订购</mp-button>
</mp-button-group>
```

## mp-box

- properties

> ratio: Number


## mp-dots

- properties

> count: Number、current: Number、 radius: String、  gap: String、color: String、activeColor: String、 activeWidth: String、width: String、height: String、radius: String

- event

> change


## mp-pk-card

- properties

> bg: String、bgOpacity: Number、  images: Array<String>、 gap: String、 deg: Number、  pLeft: String

- slot

> left、right


- events

> offset

### demo
```wxml
<view style="height: 500rpx;">
    <mp-pk-card deg="{{-10}}">
        <view slot="left" style="height: 100%; width: 100%; color: red; display: flex; align-items: flex-end;">
            Left
        </view>
        <view slot="right" style="height: 100%; width: 100%; color: red; display: flex; align-items: flex-end; justify-content: flex-end;">
            Right
        </view>
    </mp-pk-card>
</view>
```

## mp-pk-progress-bar

- properties

> height: String、 radius: String、 bg: String、 chunkWidth: String、 value: String、 left: String、 right: String、 deg: Number


## mp-image

- properties

> src: String、 lazy: Boolean、 mode: String、 radius: String、bg: String
